OC.L10N.register(
    "settings",
    {
    "Private" : "Privatus",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Matoma tik žmonėms, su kuriais pokalbių programėlėje mobiliajame įrenginyje buvo rasta atitiktis per telefono numerio integraciją",
    "Local" : "Vietinis",
    "Only visible to people on this instance and guests" : "Matoma tik žmonėms šiame egzemplioriuje ir svečiams",
    "Federated" : "Federacinis",
    "Only synchronize to trusted servers" : "Sinchronizuoti tik į patikimus serverius",
    "Published" : "Paskelbtas",
    "Synchronize to trusted servers and the global and public address book" : "Sinchronizuoti į patikimus serverius ir į visuotinę bei viešą adresų knygą",
    "Verify" : "Patikrinti",
    "Verifying …" : "Tikrinama...",
    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Groups" : "Grupės",
    "Group list is empty" : "Grupės sąrašas yra tuščias",
    "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
    "{actor} added you to group {group}" : "{actor} pridėjo jus į grupę {group}",
    "You added {user} to group {group}" : "Jūs pridėjote naudotoją {user} į grupę {group}",
    "{actor} added {user} to group {group}" : "{actor} pridėjo naudotoją {user} į grupę {group}",
    "An administrator added you to group {group}" : "Administratorius pridėjo jus į grupę {group}",
    "An administrator added {user} to group {group}" : "Administratorius pridėjo naudotoją {user} į grupę {group}",
    "{actor} removed you from group {group}" : "{actor} pašalino jus iš grupės {group}",
    "You removed {user} from group {group}" : "Jūs pašalinote naudotoją {user} iš grupės {group}",
    "{actor} removed {user} from group {group}" : "{actor} pašalino naudotoją {user} iš grupės {group}",
    "An administrator removed you from group {group}" : "Administratorius pašalino jus iš grupės {group}",
    "An administrator removed {user} from group {group}" : "Administratorius pašalino naudotoją {user} iš grupės {group}",
    "Your <strong>group memberships</strong> were modified" : "Jūsų <strong>narystės grupėse</strong> buvo modifikuotos",
    "{actor} changed your password" : "{actor} pakeitė jūsų slaptažodį",
    "You changed your password" : "Jūs pakeitėte savo slaptažodį",
    "Your password was reset by an administrator" : "Administratorius atstatė jūsų slaptažodį",
    "Your password was reset" : "Jūsų slaptažodis buvo atstatytas",
    "{actor} changed your email address" : "{actor} pakeitė jūsų el. pašto adresą",
    "You changed your email address" : "Jūs pakeitėte savo el. pašto adresą",
    "Your email address was changed by an administrator" : "Administratorius pakeitė jūsų el. pašto adresą",
    "You deleted app password \"{token}\"" : "Jūs ištrynėte programėlės slaptažodį \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Jūs pervadinote programėlės slaptažodį \"{token}\" į \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Jūs suteikėte failų sistemai prieigą prie programos slaptažodžio  „{token}“.",
    "You revoked filesystem access from app password \"{token}\"" : "Jūs atšaukėte  failų sistemos prieigą prie programos slaptažodžio „{token}“\n \n\n \n \n \n ",
    "Security" : "Saugumas",
    "You successfully logged in using two-factor authentication (%1$s)" : "Jūs sėkmingai prisijungėte, naudodami dviejų faktorių tapatybės nustatymą (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Nepavyko prisijungti, naudojant dviejų faktorių tapatybės nustatymą (%1$s)",
    "Remote wipe was started on %1$s" : "Nuotolinių duomenų ištrynimas buvo pradėtas ties %1$s",
    "Remote wipe has finished on %1$s" : "Nuotolinių duomenų ištrynimas užbaigtas ties %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Jūsų <strong>slaptažodis</strong> ar <strong>el. paštas</strong> buvo pakeisti",
    "Settings" : "Nustatymai",
    "Could not remove app." : "Nepavyko pašalinti programėlės.",
    "Could not update app." : "Nepavyko atnaujinti programėlės.",
    "Wrong password" : "Neteisingas slaptažodis",
    "Unable to change personal password" : "Nepavyko pakeisti asmeninio slaptažodžio",
    "Saved" : "Įrašyta",
    "Unable to change password. Password too long." : "Nepavyko pakeisti slaptažodžio. Slaptažodis per ilgas.",
    "Authentication error" : "Tapatybės nustatymo klaida",
    "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriaus atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
    "Administrator documentation" : "Administratoriaus dokumentacija",
    "User documentation" : "Naudotojo dokumentacija",
    "Invalid SMTP password." : "Neteisingas SMTP slaptažodis.",
    "Email setting test" : "El. pašto nustatymo testas",
    "Well done, %s!" : "Gerai padirbėjote, %s!",
    "If you received this email, the email configuration seems to be correct." : "Jeigu gavote šį laišką, tuomet atrodo, jog el. pašto konfigūracija yra teisinga.",
    "Email could not be sent. Check your mail server log" : "El. laiškas nebuvo išsiųstas. Peržiūrėkite savo pašto serverio žurnalą.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Siunčiant el. laišką atsirado problemų. Peržiūrėkite savo nustatymus. (Klaida: %s)",
    "Disabled accounts" : "Išjungtos paskyros",
    "Invalid account" : "Neteisinga paskyra",
    "Invalid mail address" : "Neteisingas pašto adresas",
    "Settings saved" : "Nustatymai įrašyti",
    "Unable to change full name" : "Nepavyko pakeisti vardo ir pavardės",
    "Unable to change email address" : "Nepavyko pakeisti el. pašto adresą",
    "Some account data was invalid" : "Kai kurie paskyros duomenys buvo neteisingi",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Norėdami patvirtinti savo „Twitter“ paskyrą, paskelbkite šį trumpą įrašą  „Twitter“ programoje (prašome, įsitikinkite kad įrašas neturi jokių jokių eilutės pertraukų):\n  ",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Norėdami patvirtinti savo Saityną, išsaugokite turinį web-root aplanke: „.well-know/CloudIdVerificationCode.txt“ (Prašome įsitikinkite, kad visas tekstas yra vienoje eilutėje):",
    "%1$s changed your password on %2$s." : "%1$s pakeitė jūsų slaptažodį %2$s",
    "Your password on %s was changed." : "Jūsų %s slaptažodis buvo pakeistas. ",
    "Your password on %s was reset by an administrator." : "Administratorius atstatė Jūsų %s slaptažodį.  ",
    "Your password on %s was reset." : "Jūsų %s slaptažodis buvo atstatytas.",
    "Password for %1$s changed on %2$s" : "%1$s slaptažodis, buvo pakeistas ant %2$s",
    "Password changed for %s" : "Pakeistas %s slaptažodis",
    "If you did not request this, please contact an administrator." : "Jeigu nebuvote to užklausę, susisiekite su administratoriumi.",
    "Your email address on %s was changed." : "Buvo pakeistas Jūsų el. pašto adress ant %s.",
    "Your email address on %s was changed by an administrator." : "Administratorius pakeitė Jūsų el. pašto adresą ant %s.",
    "Email address for %1$s changed on %2$s" : "%1$s el. pašto adresas buvo pakeistas ant %2$s. ",
    "Email address changed for %s" : "Pakeistas %s el. pašto adresas. ",
    "The new email address is %s" : "Naujasis el. pašto adresas yra %s",
    "Your %s account was created" : "Jūsų paskyra %s sukurta",
    "Welcome aboard" : "Sveikiname prisijungus",
    "Welcome aboard %s" : "%s, sveikiname prisijungus",
    "Welcome to your %s account, you can add, protect, and share your data." : "Turėdami %s paskyrą duomenis galite pridėti, apsaugoti ir jais pasidalinti.",
    "Your Login is: %s" : "Jūsų prisijungimas yra: %s",
    "Set your password" : "Nustatykite savo slaptažodį.",
    "Go to %s" : "Pereiti į %s",
    "Install Client" : "Įdiegti kliento programą",
    "Apps" : "Programėlės",
    "Personal" : "Asmeniniai",
    "Administration" : "Administravimas",
    "Users" : "Naudotojai",
    "Additional settings" : "Papildomi nustatymai",
    "Artificial Intelligence" : "Dirbtinis intelektas",
    "Administration privileges" : "Administravimo teisės",
    "Groupware" : "Grupinio darbo įranga",
    "Overview" : "Apžvalga",
    "Basic settings" : "Pagrindiniai nustatymai",
    "Sharing" : "Bendrinimas",
    "Availability" : "Pasiekiamumas",
    "Calendar" : "Kalendorius",
    "Personal info" : "Asmeninė informacija",
    "Mobile & desktop" : "Mobilieji ir darbalaukiai",
    "Email server" : "El. pašto serveris",
    "Security & setup checks" : "Saugumo ir sąrankos patikrinimai",
    "Background jobs" : "Foninės užduotys",
    "Unlimited" : "Neribotai",
    "Verifying" : "Tikrinimas",
    "Your remote address could not be determined." : "Nepavyko nustatyti jūsų nuotolinio adreso.",
    "Debug mode" : "Derinimo veiksena",
    "Debug mode is disabled." : "Derinimo veiksena yra išjungta.",
    "Disabled" : "Išjungta",
    "You are not using MySQL" : "Jūs nenaudojate MySQL",
    "MySQL is used as database and does support 4-byte characters" : "MySQL yra naudojama kaip duomenų bazė ir palaiko 4 baitų simbolius",
    "Supported" : "Palaikoma",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
    "PHP modules" : "PHP moduliai",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache modulis nėra įkeltas. Geresniam našumui rekomenduojame įkelti šį modulį į savo PHP diegimą.",
    "Database version" : "Duomenų bazės versija",
    "Unknown database platform" : "Nežinoma duomenų bazės platforma",
    "Architecture" : "Architektūra",
    "64-bit" : "64 bitų",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilio paveikslėlis, vardas, pavardė, el. paštas, telefono numeris, adresas, svetainė, „Twitter“, organizacija, vaidmuo, santrauka apie jus, biografija bei tai, ar jūsų profilis yra įjungtas, ar ne",
    "Nextcloud settings" : "Nextcloud nustatymai",
    "Here you can decide which group can access certain sections of the administration settings." : "Čia galite nuspręsti, kuri grupė galės gauti prieigą prie tam tikrų administravimo nustatymų sekcijų.",
    "None" : "Nėra",
    "Allow apps to use the Share API" : "Leisti programėlėms naudoti bendrinimo API",
    "Allow resharing" : "Leisti bendrinti iš naujo",
    "Allow sharing with groups" : "Leisti bendrinti su grupėmis",
    "Restrict users to only share with users in their groups" : "Apriboti naudotojus ir leisti jiems bendrinti tik su naudotojais savo grupėse",
    "Allow public uploads" : "Leisti viešus įkėlimus",
    "Always ask for a password" : "Visada prašyti slaptažodžio",
    "Enforce password protection" : "Priverstinė apsauga slaptažodžiu",
    "Set default expiration date for shares" : "Nustatyti viešiniams numatytąją galiojimo pabaigos datą",
    "Enforce expiration date" : "Priverstinė galiojimo pabaigos data",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Rodyti atsakomybės ribojimo tekstą įkėlimo per viešąją nuorodą puslapyje (rodomas tik tada, kai failų sąrašas yra paslėptas)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Šis tekstas bus rodomas viešų nuorodų įkėlimo puslapyje, kai failų sąrašas bus paslėptas.",
    "Default share permissions" : "Numatytieji viešinių leidimai",
    "Two-Factor Authentication" : "Dviejų faktorių tapatybės nustatymas",
    "Enforce two-factor authentication" : "Priversti naudoti dviejų faktorių tapatybės nustatymą",
    "Limit to groups" : "Apriboti iki grupių",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Priverstinis dviejų faktorių tapatybės nustatymas gali būti nustatytas tik tam tikroms grupėms.",
    "Two-factor authentication is enforced for all members of the following groups." : "Dviejų faktorių tapatybės nustatymas yra priverstinis visiems šių grupių nariams.",
    "Enforced groups" : "Priverstines grupės",
    "Two-factor authentication is not enforced for members of the following groups." : "Dviejų faktorių tapatybės nustatymas nėra priverstinis šių grupių nariams.",
    "Excluded groups" : "Pašalintos grupės",
    "Save changes" : "Įrašyti pakeitimus",
    "Update to {update}" : "Atnaujinti į {update}",
    "Remove" : "Šalinti",
    "Featured" : "Siūlomos",
    "This app is supported via your current Nextcloud subscription." : "Ši programėlė yra palaikoma per jūsų esamą Nextcloud prenumeratą.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Siūlomos programėlės yra kuriamos bendruomenės viduje ir jas kuria bendruomenė. Šios programėlės siūlo svarbiausią funkcionalumą ir yra paruoštos kasdieniam naudojimui.",
    "All apps are up-to-date." : "Visos programėlės yra naujausios laidos.",
    "Icon" : "Piktograma",
    "Name" : "Vardas",
    "Version" : "Versija",
    "Level" : "Lygmuo",
    "Actions" : "Veiksmai",
    "Results from other categories" : "Rezultatai iš kitų kategorijų",
    "No apps found for your version" : "Jūsų versijai programėlių nėra",
    "Disable all" : "Išjungti visas",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n programėlei yra prieinamas atnaujinimas","%n programėlėms yra prieinamas atnaujinimas","%n programėlių yra prieinamas atnaujinimas","%n programėlei yra prieinamas atnaujinimas"],
    "_Update_::_Update all_" : ["Atnaujinti","Atnaujinti visas","Atnaujinti visas","Atnaujinti visas"],
    "Loading" : "Įkeliama",
    "Fetching the latest news…" : "Gaunamos paskiausios naujienos…",
    "Previous slide" : "Ankstesnė skaidrė",
    "Next slide" : "Kita skaidrė",
    "Daemon" : "Tarnyba",
    "Type" : "Tipas",
    "Display Name" : "Rodomas vardas",
    "Description" : "Aprašas",
    "Details" : "Išsamiau",
    "All" : "Viskas",
    "Limit app usage to groups" : "Programos panaudojimas ribojamas grupėms",
    "No results" : "Rezultatų nėra",
    "Update to {version}" : "Atnaujinti į versiją {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos žemiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos aukščiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ši programėlė negali būti įdiegta, nes nėra patenkintos žemiau išvardintos priklausomybės:",
    "Author" : "Autorius",
    "Categories" : "Kategorijos",
    "Resources" : "Ištekliai",
    "Documentation" : "Dokumentacija",
    "Report a bug" : "Pranešti apie klaidą",
    "Request feature" : "Prašyti funkcionalumo",
    "Ask questions or discuss" : "Užduokite klausimus arba diskutuokite",
    "Rate" : "Įvertinkite",
    "View in store" : "Rodyti parduotuvėje",
    "Visit website" : "Aplankyti svetainę",
    "Admin documentation" : "Administratoriaus dokumentacija",
    "Developer documentation" : "Plėtotojo dokumentacija",
    "Changelog" : "Keitinių žurnalas",
    "Marked for remote wipe" : "Pažymėtas nuotolinių duomenų ištrynimui",
    "Device settings" : "Įrenginio nustatymai",
    "Allow filesystem access" : "Leisti prieigą prie failų sistemos",
    "Rename" : "Pervadinti",
    "Revoke" : "Panaikinti",
    "Wipe device" : "Ištrinti duomenis įrenginyje",
    "Google Chrome for Android" : "Google Chrome, skirta Android",
    "{productName} iOS app" : "{productName} „iOS“ programėlė",
    "{productName} Android app" : "{productName} „Android“ programėlė",
    "This session" : "Šis seansas",
    "{client} - {version} ({system})" : "{client} – {version} ({system})",
    "{client} - {version}" : "{client} – {version}",
    "Device" : "Įrenginys",
    "Last activity" : "Paskutinė veikla",
    "Devices & sessions" : "Įrenginiai ir seansai",
    "Web, desktop and mobile clients currently logged in to your account." : "Saityno, darbalaukio ir mobilieji klientai, kurie šiuo metu yra prisijungę prie jūsų paskyros.",
    "App name" : "Programėlės pavadinimas",
    "Create new app password" : "Sukurti naują programėlės slaptažodį",
    "Error while creating device token" : "Klaida, kuriant įrenginio prieigos raktą",
    "Login" : "Prisijungti",
    "Password" : "Slaptažodis",
    "Show QR code for mobile apps" : "Rodyti mobiliųjų programėlių QR kodą",
    "Could not copy app password. Please copy it manually." : "Nepavyko nukopijuoti programos slaptažodžio. Nukopijuokite jį ranka.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Tam, kad serveris tinkamai veiktų, yra svarbu teisingai sukonfigūruoti fonines užduotis. „Cron“ yra rekomenduojamas nustatymas. Išsamesnei informacijai žiūrėkite dokumentaciją.",
    "Last job execution ran {time}. Something seems wrong." : "Paskutinis užduoties vykdymas buvo atliktas {time}. Atrodo, kad kažkas nutiko.",
    "Last job ran {relativeTime}." : "Paskutinis užduoties vykdymas buvo atliktas {relativeTime}.",
    "Background job did not run yet!" : "Foninės užduotys kol kas nebuvo vykdomos!",
    "AJAX" : "„AJAX“",
    "Webcron" : "„Webcron“",
    "Cron (Recommended)" : "„Cron“ (Rekomenduojama)",
    "Use system cron service to call the cron.php file every 5 minutes." : "Naudokite sistemos cron paslaugą, kad kas 5 minutes iškviestumėte cron.php failą.",
    "Unable to update background job mode" : "Nepavyko atnaujinti foninių užduočių veiksenos",
    "Profile" : "Profilis",
    "Enable" : "Įjungti",
    "Server-side encryption" : "Šifravimas serverio pusėje",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifravimas serverio pusėje leidžia užšifruoti failus, kurie yra įkelti į serverį. Įjungti tik ik būtinais atvejais.",
    "Enable server-side encryption" : "Įjungti šifravimą serverio pusėje",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Nuo to momento kai šifravimas aktyvuotas, visi failai įkelti į serverį bus užšifruoti ir saugomi serveryje. Vėliau išjungti šifravimą galėsite tik jei šifravimo modulius turi tokią galimybę, ir visos sąlygos (pvz. atstatymo rakto nustatymas) išpildytos.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Vien tik šifravimas negarantuoja sistemos saugumo. Išsamesnei informacijai apie tai, kaip veikia šifravimo programėlė ir galimus naudojimo scenarijus, žiūrėkite dokumentaciją.",
    "Be aware that encryption always increases the file size." : "Turėkite omenyje, kad šifravimas visada padidina failų dydį.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Visada yra gerai daryti reguliarias atsargines duomenų kopijas. Esant šifravimui, nepamirškite kartu su savo duomenų atsargine kopija, pasidaryti ir šifravimo raktų atsarginę kopiją.",
    "This is the final warning: Do you really want to enable encryption?" : "Tai yra paskutinis įspėjimas: Ar tikrai norite įjungti šifravimą?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Neįkeltas joks šifravimo modulis, įjunkite šifravimo modulį programėlės meniu.",
    "Select default encryption module:" : "Pasirinkite numatytąjį šifravimo modulį:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį. Įjunkite „Numatytąjį šifravimo modulį“ ir paleiskite komandą {command}",
    "Cancel" : "Atšaukti",
    "Confirm" : "Patvirtinti",
    "Submit" : "Pateikti",
    "Rename group" : "Pervadinti grupę",
    "Remove group" : "Šalinti grupę",
    "Current password" : "Dabartinis slaptažodis",
    "New password" : "Naujas slaptažodis",
    "Change password" : "Pakeisti slaptažodį",
    "Your profile picture" : "Jūsų profilio paveikslėlis",
    "Remove profile picture" : "Šalinti profilio paveikslėlį",
    "The file must be a PNG or JPG" : "Failas privalo būti PNG ar JPG tipo",
    "Picture provided by original account" : "Paveikslėlis gautas iš pagrindinės paskyros",
    "Set as profile picture" : "Nustatyti kaip profilio paveikslėlį",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Turėkite omenyje, kad gali praeiti iki 24 valandų, kol jūsų profilis bus visur atnaujintas.",
    "Error setting profile picture" : "Klaida nustatant profilio paveikslėlį",
    "Error cropping profile picture" : "Klaida apkerpant profilio paveikslėlį",
    "Error saving profile picture" : "Klaida įrašant profilio paveikslėlį",
    "Error removing profile picture" : "Klaida šalinant profilio paveikslėlį",
    "Your biography" : "Jūsų biografija",
    "You are a member of the following groups:" : "Jūs esate šių grupių narys:",
    "Your full name" : "Jūsų visas vardas",
    "Primary email for password reset and notifications" : "Pirminis el. paštas, skirtas slaptažodžio atstatymui bei pranešimams",
    "Email options" : "El. pašto parinktys",
    "Remove primary email" : "Šalinti pirminį el. paštą",
    "Delete email" : "Ištrinti el. paštą",
    "This address is not confirmed" : "Šis adresas nėra patvirtintas",
    "Set as primary email" : "Nustatyti kaip pirminį el. paštą",
    "Additional email address {index}" : "Papildomas el. pašto adresas {index}",
    "Unable to delete primary email address" : "Nepavyko ištrinti pirminio el. pašto adreso",
    "Unable to update primary email address" : "Nepavyko atnaujinti pirminio el. pašto adreso",
    "Unable to add additional email address" : "Nepavyko pridėti papildomo el. pašto adreso",
    "Unable to update additional email address" : "Nepavyko atnaujinti papildomo el. pašto adreso",
    "Unable to delete additional email address" : "Nepavyko ištrinti papildomo el. pašto adreso",
    "No email address set" : "Nenustatytas joks el. pašto adresas",
    "Your headline" : "Santrauka apie jus",
    "Languages" : "Kalbos",
    "Help translate" : "Padėkite išversti",
    "Unable to update language" : "Nepavyko atnaujinti kalbos",
    "No language set" : "Nenustatyta jokia kalba",
    "Locales" : "Lokalės",
    "Week starts on {firstDayOfWeek}" : "Savaitės pradžia yra {firstDayOfWeek}",
    "Unable to update locale" : "Nepavyko atnaujinti lokalės",
    "Your city" : "Jūsų miestas",
    "Your organisation" : "Jūsų organizacija",
    "Your phone number" : "Jūsų telefono numeris",
    "Edit your Profile visibility" : "Taisyti savo profilio matomumą",
    "Unable to update profile enabled state" : "Nepavyko atnaujinti profilio įjungimo būsenos",
    "Unable to update visibility of {displayId}" : "Nepavyko atnaujinti {displayId} matomumo",
    "Your role" : "Jūsų vaidmuo",
    "Your website" : "Jūsų svetainė",
    "Unable to update {property}" : "Nepavyko atnaujinti {property}",
    "Add additional email" : "Pridėti papildomą el. paštą",
    "Add" : "Pridėti",
    "Create" : "Sukurti",
    "Change" : "Keisti",
    "Delete" : "Ištrinti",
    "Reshare" : "Pakartotinai bendrinti",
    "Loading accounts …" : "Įkeliamos paskyros ...",
    "Default language" : "Numatytoji kalba",
    "Common languages" : "Bendrosios kalbos",
    "Other languages" : "Kitos kalbos",
    "Password change is disabled because the master key is disabled" : "Slaptažodžių keitimas išjungtas, nes yra išjungtas pagrindinis raktas",
    "New account" : "Nauja paskyra",
    "Display name" : "Rodomas vardas",
    "Email" : "El. paštas",
    "Quota" : "Limitas",
    "Language" : "Kalba",
    "Add new account" : "Pridėti naują paskyrą",
    "Avatar" : "Avataras",
    "Account name" : "Paskyros pavadinimas",
    "Group admin for" : "Grupės administratorius",
    "Storage location" : "Saugyklos vieta",
    "Last login" : "Paskutinis prisijungimas",
    "Account actions" : "Veiksmai su paskyra",
    "Loading account …" : "Įkeliama paskyra…",
    "Set new password" : "Nustatyti naują slaptažodį",
    "You do not have permissions to see the details of this account" : "Jūs neturite leidimo matyti išsamesnę informaciją apie šią paskyrą",
    "Set new email address" : "Nustatyti naują el. pašto adresą",
    "Add account to group" : "Pridėti paskyrą į grupę",
    "Set the language" : "Nustatyti kalbą",
    "{size} used" : "{size} naudojama",
    "Delete account" : "Ištrinti paskyrą",
    "Disconnect all devices and delete local data" : "Atjungti visus įrenginius ir ištrinti vietinius duomenis",
    "Disable account" : "Išjungti paskyrą",
    "Enable account" : "Įjungti paskyrą",
    "Resend welcome email" : "Siųsti dar kartą pasveikinimo el. laišką",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Pametus įrenginį arba pasikeitus darbo santykiams su organizacija, galima nuotoliniu būdu išvalyti „Nextcloud“ duomenis iš visų įrenginių, susietų su {userid}.  Veikia tik su prie interneto prijungtais įrenginiais.",
    "Remote wipe of devices" : "Nuotolinių duomenų įrenginiuose ištrynimas",
    "Wipe {userid}'s devices" : "Ištrinti duomenis naudotojo {userid} įrenginiuose",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Pilnai ištrinta {userid} paskyra, įskaitant visus asmeninius failus, programos duomenis ir pan. ",
    "Account deletion" : "Paskyros ištrynimas",
    "Delete {userid}'s account" : "Ištrinti naudotojo {userid} paskyrą",
    "Password was successfully changed" : "Slaptažodis buvo sėkmingai pakeistas",
    "Email was successfully changed" : "El. paštas buvo sėkmingai pakeistas",
    "Welcome mail sent!" : "Pasveikinimo laiškas išsiųstas!",
    "Done" : "Atlikta",
    "Edit" : "Taisyti",
    "Visibility" : "Matomumas",
    "Show language" : "Rodyti kalbą",
    "Show storage path" : "Rodyti saugyklos kelią",
    "Show last login" : "Rodyti paskutinį prisijungimą",
    "Sorting" : "Rikiavimas",
    "Send email" : "Siųsti el. paštą",
    "Default quota" : "Numatytasis leidžiamas duomenų kiekis",
    "Select default quota" : "Pasirinkite numatytą leidžiamą duomenų kiekį ",
    "Passwordless authentication requires a secure connection." : "Tapatybės nustatymas be slaptažodžio reikalauja saugaus ryšio.",
    "Add WebAuthn device" : "Pridėti WebAuthn įrenginį",
    "Please authorize your WebAuthn device." : "Prašome, autorizikuote savo WebAuthn įrenginį.",
    "Adding your device …" : "Pridedamas jūsų įrenginys …",
    "Server error while trying to complete WebAuthn device registration" : "Serverio klaida, bandant pabaigti WebAuthn įrenginio regsitraciją",
    "Unnamed device" : "Įrenginys be pavadinimo",
    "Passwordless Authentication" : "Tapatybės nustatymas be slaptažodžio",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Nustatykite savo paskyrai tapatybės nustatymą be slaptažodžio, pagal FIDO2 standartą.",
    "No devices configured." : "Nėra sukonfiguruotų įrenginių.",
    "The following devices are configured for your account:" : "Jūsų paskyrai sukonfiguruoti šie įrenginiai:",
    "Your browser does not support WebAuthn." : "Jūsų naršyklė nepalaiko WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Būdami administratoriumi, galite reguliuoti bendrinimo elgseną. Išsamesnei informacijai, žiūrėkite dokumentaciją.",
    "All accounts" : "Visos paskyros",
    "Admins" : "Administratoriai",
    "Creating group…" : "Kuriama grupė…",
    "Create group" : "Sukurti grupę",
    "Group name" : "Grupės pavadinimas",
    "Failed to create group" : "Nepavyko sukurti grupės",
    "Sending…" : "Siunčiama…",
    "Email sent" : "El. paštas išsiųstas",
    "Location" : "Vieta",
    "Profile picture" : "Profilio paveikslėlis",
    "About" : "Apie",
    "Date of birth" : "Gimimo data",
    "Full name" : "Vardas, pavardė",
    "Additional email" : "Papildomas el. paštas",
    "Headline" : "Santrauka",
    "Organisation" : "Organizacija",
    "Phone number" : "Telefono numeris",
    "Role" : "Vaidmuo",
    "Website" : "Svetainė",
    "Profile visibility" : "Profilio matomumas",
    "Locale" : "Lokalė",
    "First day of week" : "Pirmoji savaitės diena",
    "Your apps" : "Jūsų programėlės",
    "Active apps" : "Aktyvios programėlės",
    "Disabled apps" : "Išjungtos programėlės",
    "Updates" : "Atnaujinimai",
    "App bundles" : "Programėlių rinkiniai",
    "Featured apps" : "Siūlomos programėlės",
    "Supported apps" : "Palaikomos programėlės",
    "Show to everyone" : "Rodyti visiems",
    "Hide" : "Slėpti",
    "Download and enable" : "Atsisiųsti ir įjungti",
    "Disable" : "Išjungti",
    "The app will be downloaded from the App Store" : "Programėlė bus atsisiųsta iš programėlių parduotuvės",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ši programėlė nėra pažymėta kaip suderinama su jūsų Nextcloud versija. Jei tęsite, vis tiek galėsite įdiegti programėlę. Turėkite omenyje, kad programėlė gali neveikti taip, kaip tikimasi.",
    "Never" : "Niekada",
    "An error occurred during the request. Unable to proceed." : "Užklausos metu įvyko klaida. Nepavyksta tęsti.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Klaida: Ši programėlė negali būti įjungta, nes ji neigiamai veikia serverio stabilumą",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Programėlė įjungta, tačiau turi būti atnaujinta. Po 5 sekundžių būsite peradresuoti į atnaujinimo puslapį.",
    "Do you really want to wipe your data from this device?" : "Ar tikrai norite ištrinti šiame įrenginyje esančius savo duomenis?",
    "Confirm wipe" : "Patvirtinti duomenų ištrynimą",
    "Error while wiping the device with the token" : "Įvyko klaida valant įrenginį panaudojant raktą",
    "Error while updating device token name" : "Įvyko klaida atnaujinant įrenginio prieigos rakto pavadinimą",
    "Error while updating device token scope" : "Įvyko klaida atnaujinant įrenginio prieigos rakto taikymą",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iš jūsų tinklo buvo per daug užklausų. Bandykite dar kartą vėliau arba, jeigu tai klaida, susisiekite su savo administratoriumi.",
    "Error" : "Klaida",
    "Forum" : "Forumas",
    "Legal notice" : "Teisinis pranešimas",
    "Privacy policy" : "Privatumo politika",
    "SSL" : "SSL",
    "Open documentation" : "Atverti dokumentaciją",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Svarbu nustatyti šį serverį, kad galėtumėte siųsti el. laiškus, kaip, pavyzdžiui, slaptažodžio atstatymą ar pranešimus.",
    "Send mode" : "Siuntimo veiksena",
    "Encryption" : "Šifravimas",
    "Sendmail mode" : "El. pašto siuntimo veiksena",
    "From address" : "Siuntėjo adresas",
    "Server address" : "Serverio adresas",
    "Port" : "Prievadas",
    "Authentication" : "Tapatybės nustatymas",
    "Authentication required" : "Reikalingas tapatybės nustatymas",
    "Credentials" : "Prisijungimo duomenys",
    "SMTP Password" : "SMTP slaptažodis",
    "Save" : "Įrašyti",
    "Test and verify email settings" : "Išbandyti ir patikrinti el. pašto nustatymus",
    "Security & setup warnings" : "Saugumo ir sąrankos įspėjimai",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Siekiant jūsų egzemplioriaus saugumo ir našumo, yra svarbu, kad viskas būtų teisingai sukonfigūruota. Norėdami jums padėti, atliekame tam tikrus automatinius patikrinimus. Išsamesnei informacijai, žiūrėkite susietą dokumentaciją.",
    "All checks passed." : "Visi patikros rezultatai teigiami.",
    "There are some errors regarding your setup." : "Yra klaidų, susijusių su jūsų sąranką.",
    "There are some warnings regarding your setup." : "Yra įspėjimų, susijusių su jūsų sąranka.",
    "Checking for system and security issues." : "Tikrinamos sistemos ir saugumo problemos.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Dar kartą peržiūrėkite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">įdiegimo vadovą ↗</a> bei patikrinkite ar <a href=\"%2$s\">žurnale</a> nėra jokių klaidų ar įspėjimų.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Patikrinkite savo Nextcloud saugumą naudodamiesi <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">mūsų saugumo nuskaitymu ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Priežastys, kodėl turėtumėte naudoti Nextcloud savo organizacijoje",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Sukurta {communityopen}Nextcloud bendruomenės{linkclose}, {githubopen}pirminis kodas{linkclose} yra licencijuotas pagal {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Spauskite „Patinka“ mūsų „Facebook“ puslapyje",
    "Follow us on Mastodon" : "Sekite mus Mastodon",
    "Check out our blog" : "Peržvelkite mūsų tinklaraštį",
    "Subscribe to our newsletter" : "Prenumeruokite mūsų naujienlaiškį",
    "Use a second factor besides your password to increase security for your account." : "Be savo slaptažodžio naudokite ir antrąjį faktorių, kad padidintumėte savo paskyros saugumą.",
    "No user supplied" : "Nepateiktas naudotojas",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Pateikite administratoriaus atkūrimo slaptažodį; kitu atveju visi naudotojo duomenis bus prarasti.",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Prieš tai, kai galėsite siųsti bandomuosius el. laiškus, turite nusistatyti naudotojo el. paštą. Norėdami tai atlikti, pereikite į %s.",
    "Invalid user" : "Neteisingas naudotojas",
    "Your username is: %s" : "Jūsų naudotojo vardas yra: %s",
    "Logged in user must be a subadmin" : "Prisijungęs naudotojas privalo būti administratoriaus pavaduotojas",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Yra naudojama MariaDB versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios MariaDB versijos ir reikalauja 10.2 ar naujesnės versijos.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Yra naudojama MySQL versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios MySQL versijos ir reikalauja MySQL 8.0 arba MariaDB 10.2, ar naujesnės versijos.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Yra naudojama PostgreSQL versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios PostgreSQL versijos ir reikalauja PostgreSQL 9.6 ar naujesnės versijos.",
    "Exclude groups from sharing" : "Išskirti grupes iš bendrinimo",
    "These groups will still be able to receive shares, but not to initiate them." : "Šios grupės vis tiek galės gauti viešinius, tačiau negalės jų inicijuoti.",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dviejų faktorių tapatybės nustatymas gali būti priverstinis visiems naudotojams ir tam tikroms grupėms. Jeigu naudotojai ar grupės neturės sukonfigūruoto dviejų faktorių teikėjo, tuomet jie negalės prisijungti prie sistemos.",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Jei nepasirinkta nė viena grupė, 2FA įjungiama visiems, išskyrus pašalintų grupių narius. Jei pasirenkamos grupės, visiems jų nariams įjungiama 2FA. Jei vartotojas yra ir pasirinktoje, ir pašalintoje grupėje,  2FA yra įjungiamas. ",
    "{license}-licensed" : "Licencijuota pagal {license}",
    "Username" : "Naudotojo vardas",
    "Execute one task with each page loaded. Use case: Single user instance." : "Su kiekvienu įkeltu puslapiu vykdyti po vieną užduotį. Naudojimo atvejis: Egzempliorius su vienu naudotoju.",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "„cron.php“ yra registruojamas „webcron“ tarnyboje, kad kas 5 minutes per HTTP būtų iškviečiamas failas „cron.php“. Naudojimo atvejis: Labai mažas egzempliorius (priklausomai nuo našumo, 1–5 naudotojai).",
    "The cron.php needs to be executed by the system user \"{user}\"." : "Failą „cron.php“ turi vykdyti sistemos naudotojas „{user}“.",
    "You are using <strong>{usage}</strong>" : "Jūs naudojate <strong>{usage}</strong>",
    "Additional emails" : "Papildomi el. paštai",
    "Enable Profile" : "Įjungti profilį",
    "Loading users …" : "Įkeliami naudotojai…",
    "New user" : "Naujas naudotojas",
    "Add new user" : "Pridėti naują naudotoją",
    "User backend" : "Naudotojo vidinė pusė",
    "Loading user …" : "Įkeliamas naudotojas…",
    "You do not have permissions to see the details of this user" : "Jūs neturite leidimų matyti išsamesnę informaciją apie šį naudotoją",
    "Add user to group" : "Pridėti naudotoją į grupę",
    "Set user as admin for" : "Nustatyti vartotoją kaip administratorių ",
    "Select user quota" : "Pasirinkite leidžiamą duomenų kiekį naudotojui",
    "Delete user" : "Ištrinti naudotoją",
    "Wipe all devices" : "Ištrinti duomenis visuose įrenginiuose",
    "Disable user" : "Išjungti naudotoją",
    "Enable user" : "Įjungti naudotoją",
    "Toggle user actions menu" : "Perjungti vartotojo veiksmų meniu ",
    "Show user backend" : "Rodyti naudotojo vidinę pusę",
    "Name your device" : "Pavadinkite savo įrenginį",
    "Server error while trying to add WebAuthn device" : "Serverio klaida, bandant pridėti WbAuthn įrenginį",
    "by {author}\n{license}" : "pagal {author}\n{license}",
    "Active users" : "Aktyvūs naudotojai",
    "Disabled users" : "Išjungti naudotojai",
    "Creating group …" : "Kuriama grupė…",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Neprieinama, nes su naudotoju susijusios informacijos paskelbimas į paieškos serverį yra neleidžiamas. Jei turite klausimų, susisiekite su savo sistemos administratoriumi",
    "Show to logged in users only" : "Rodyti tik prisijungusiems naudotojams",
    "SMTP Username" : "SMTP naudotojo vardas",
    "Follow us on Twitter" : "Sekite mus Twitter",
    "Active accounts" : "Aktyvios paskyros"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
